==> unixODBC-1.8.13.tar.gz: unixODBC-1.8.13/Drivers/txt/SQLBindCol.c <==
/**********************************************************************
 * SQLBindCol
 *
 **********************************************************************
 *
 * This code was created by Peter Harvey (mostly during Christmas 98/99).
 * This code is LGPL. Please ensure that this message remains in future
 * distributions and uses of this code (thats about all I get out of it).
 * - Peter Harvey pharvey@codebydesign.com
 *
 **********************************************************************/

#include "driver.h"

/* THIS IS THE CORRECT SYNTAX....
SQLRETURN SQLBindCol(	SQLHSTMT        hDrvStmt,
						SQLUSMALLINT    nCol,
						SQLSMALLINT     nTargetType,
						SQLPOINTER      pTargetValue,
						SQLINTEGER      nTargetValueMax,
						SQLINTEGER      *pnLengthOrIndicator )
AND THIS IS WHAT WORKS... */						
SQLRETURN SQLBindCol(	SQLHSTMT	hDrvStmt,
						UWORD		nCol,					/* 1 based */
						SWORD		nTargetType,
						PTR			pTargetValue,
						SDWORD      nTargetValueMax,
						SDWORD      *pnLengthOrIndicator )
{
    HDRVSTMT 		hStmt	= (HDRVSTMT)hDrvStmt;
	HBOUNDCOLUMN	pBoundColumn;			

    /* SANITY CHECKS */
    if( NULL == hStmt )
        return SQL_INVALID_HANDLE;

	sprintf( hStmt->szSqlMsg, "hStmt=$%08lX nCol=%5d", hStmt, nCol );
    logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING, hStmt->szSqlMsg );

	if ( !hStmt->hStmtExtras->hBoundCols )
	{
		logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING, "SQL_ERROR No result set." );
		return SQL_ERROR;
	}

	if ( nCol < 1 || nCol > hStmt->hStmtExtras->hBoundCols->nItems )
	{
		sprintf( hStmt->szSqlMsg, "SQL_ERROR Column %d is out of range. Range is 1 - %s", nCol, hStmt->hStmtExtras->hBoundCols->nItems );
		logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING, hStmt->szSqlMsg );
		return SQL_ERROR;
	}

	if ( pTargetValue == NULL )
	{
		logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING, "SQL_ERROR Invalid data pointer" );
		return SQL_ERROR;
	}

	if ( pnLengthOrIndicator != NULL )
		*pnLengthOrIndicator = 0;

	/* SET DEFAULTS */

	/* validate length etc */

	/* store app col pointer */
    lstGoto( hStmt->hStmtExtras->hBoundCols, nCol-1 );
	pBoundColumn						= (HBOUNDCOLUMN)lstGet( hStmt->hStmtExtras->hBoundCols );
	pBoundColumn->nTargetType			= nTargetType;
	pBoundColumn->nTargetValueMax		= nTargetValueMax;
	pBoundColumn->pnLengthOrIndicator	= pnLengthOrIndicator;
	pBoundColumn->pTargetValue			= pTargetValue;

    logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_INFO, LOG_INFO, "SQL_SUCCESS" );
    return SQL_SUCCESS;
}

==> unixODBC-2.0.5.tar.gz: unixODBC-2.0.5/Drivers/txt/SQLBindCol.c <==
/**********************************************************************
 * SQLBindCol
 *
 **********************************************************************
 *
 * This code was created by Peter Harvey (mostly during Christmas 98/99).
 * This code is LGPL. Please ensure that this message remains in future
 * distributions and uses of this code (thats about all I get out of it).
 * - Peter Harvey pharvey@codebydesign.com
 *
 **********************************************************************/

#include "driver.h"

/* THIS IS THE CORRECT SYNTAX....
SQLRETURN SQLBindCol(	SQLHSTMT        hDrvStmt,
						SQLUSMALLINT    nCol,
						SQLSMALLINT     nTargetType,
						SQLPOINTER      pTargetValue,
						SQLINTEGER      nTargetValueMax,
						SQLINTEGER      *pnLengthOrIndicator )
AND THIS IS WHAT WORKS... */						
SQLRETURN SQLBindCol(	SQLHSTMT	hDrvStmt,
						UWORD		nCol,					/* 1 based */
						SWORD		nTargetType,
						PTR			pTargetValue,
						SDWORD      nTargetValueMax,
						SDWORD      *pnLengthOrIndicator )
{
    HDRVSTMT 		hStmt	= (HDRVSTMT)hDrvStmt;
	HBOUNDCOLUMN	pBoundColumn;			

    /* SANITY CHECKS */
    if( NULL == hStmt )
        return SQL_INVALID_HANDLE;

	sprintf( hStmt->szSqlMsg, "hStmt=$%08lX nCol=%5d", hStmt, nCol );
    logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING, hStmt->szSqlMsg );

	if ( !hStmt->hTable )
	{
		logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING, "SQL_ERROR No result set." );
		return SQL_ERROR;
	}

	if ( nCol < 1 || nCol > hStmt->hTable->hColumns->nItems )
	{
		sprintf( hStmt->szSqlMsg, "SQL_ERROR Column %d is out of range. Range is 1 - %d", nCol, hStmt->hTable->hColumns->nItems );
		logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING, hStmt->szSqlMsg );
		return SQL_ERROR;
	}

	if ( pTargetValue == NULL )
	{
		logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_WARNING, LOG_WARNING, "SQL_ERROR Invalid data pointer" );
		return SQL_ERROR;
	}

	if ( pnLengthOrIndicator != NULL )
		*pnLengthOrIndicator = 0;

    pBoundColumn = (HBOUNDCOLUMN)malloc( sizeof(BOUNDCOLUMN) );
	pBoundColumn->nTargetType			= nTargetType;
	pBoundColumn->nTargetValueMax		= nTargetValueMax;
	pBoundColumn->pnLengthOrIndicator	= pnLengthOrIndicator;
	pBoundColumn->pTargetValue			= pTargetValue;
    lstGoto( hStmt->hTable->hColumns, nCol-1 );
    pBoundColumn->hColumn               = (HTXTCOLUMN)lstGet( hStmt->hTable->hColumns );

    lstAppend( hStmt->hBoundCols, pBoundColumn );

    logPushMsg( hStmt->hLog, __FILE__, __FILE__, __LINE__, LOG_INFO, LOG_INFO, "SQL_SUCCESS" );

    return SQL_SUCCESS;
}
